// Copyright (C) 2004, Brian Enigma <enigma at netninja.com>
// This file is part of BarcodeProcessor.
//
// BarcodeProcessor is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// BarcodeProcessor is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Foobar; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
package org.ninjasoft.barcodeprocessor;

import java.util.*;

/**
 * Class to hold parsed barcode image data.  Supports not just narrow/wide,
 * but 1x, 2x, 3x, and 4x.
 * 
 * @author enigma
 */
public class BarcodeData {
    private Vector data = new Vector();
    
    public void addNarrowSpace() {
        addSpace(1);
    }
    public void addWideSpace() {
        addSpace(2);
    }
    public void addNarrowBar() {
        addBar(1);
    }
    public void addWideBar() {
        addBar(2);
    }
    public void addSpace(int size) throws RuntimeException {
        // Sanity check the size
        if ((size < 1) || (size > 4))
            throw new RuntimeException("Space needs to be between 1 and 4");
        // Sanity check the order: can't have two spaces or two bars in a row
        if (this.data.size() > 0) {
            if (((String) data.get(data.size() - 1)).endsWith("s"))
                throw new RuntimeException("Can't have two spaces in a row");
        }
        this.data.add(size + "s");
    }
    public void addBar(int size) throws RuntimeException {
        // Sanity check the size
        if ((size < 1) || (size > 4))
            throw new RuntimeException("Space needs to be between 1 and 4");
        // Sanity check the order: can't have two spaces or two bars in a row
        if (this.data.size() > 0) {
            if (((String) data.get(data.size() - 1)).endsWith("b"))
                throw new RuntimeException("Can't have two spaces in a row");
        }
        data.add(size + "b");
    }
    public String toString() {
        StringBuffer result = new StringBuffer();
        for (Iterator i = this.data.iterator(); i.hasNext(); ) {
            result.append(i.next().toString());
            result.append(" ");
        }
        return result.toString();
    }
    public String toCompactString() {
        StringBuffer result = new StringBuffer();
        for (Iterator i = this.data.iterator(); i.hasNext(); ) {
            String element = (String) i.next();
            if (element.startsWith("1"))
                result.append(".");
            else
                result.append("-");
        }
        result.append("\n");
        boolean bar = ((String) this.data.get(0)).endsWith("b");
        for (int i=0; i<this.data.size(); i++) {
            result.append(bar ? "|" : " ");
            bar = !bar;
        }
        result.append("\n");
        return result.toString();
        
    }
}
